.. MedCAT documentation master file, created by
   sphinx-quickstart on Wed Feb 16 14:41:03 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Medical Concept Annotation Toolkit Documentation
================================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   main.md

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
